function z = mtimes(x,y)
%PDERIV/MTIMES	Matrix multiplication
%   Z = X * Y computes the derivative representation of the matrix product X*Y

if isscalar(x) || isscalar(y)
    z = times(x, y);
elseif ~isobject(x)
    y.v = x * y.v;
    y.d = pdmap1(@(yd) mtimes(x, yd), y.d);
    z = y;
elseif ~isobject(y)
    x.v = x.v * y;
    x.d = pdmap1(@(xd) mtimes(xd, y), x.d);
    z = x;
else
    x0 = pderiv_d0(x);
    y0 = pderiv_d0(y);
    x.v = x.v * y.v;
    x.d = pdmap1(@(xd) mtimes(xd, y0), x.d) + pdmap1(@(yd) mtimes(x0, yd), y.d);
    z = x;
end
